@@ -435,7 +435,8 @@ class ExporterFootprintKicad:
     def get_ki_footprint(self) -> KiFootprint:
         return self.output
 
-    def export(self, output_path: str) -> None:
+    def export(self, output_path: str, is_project_relative: bool) -> None:
+
         ki = self.output
         ki_lib = ""
 
@@ -486,8 +487,11 @@ class ExporterFootprintKicad:
             ki_lib += KI_TEXT.format(**vars(text))
 
         if ki.model_3d is not None:
+            model_3d_path = output_path
+            if is_project_relative:
+                model_3d_path = "${KIPRJMOD}/" + model_3d_path.split("/")[-1]
             ki_lib += KI_MODEL_3D.format(
-                file_3d=f"{output_path}.3dshapes/{ki.model_3d.name}.wrl",
+                file_3d=f"{model_3d_path}.3dshapes/{ki.model_3d.name}.wrl",
                 pos_x=ki.model_3d.translation.x,
                 pos_y=ki.model_3d.translation.y,
                 pos_z=ki.model_3d.translation.z,
