@@ -202,8 +202,8 @@ def convert_ee_paths(
 def convert_to_kicad(ee_symbol: EeSymbol, kicad_version: KicadVersion) -> KiSymbol:
 
     ki_info = KiSymbolInfo(
-        name=ee_symbol.info.name.replace(" ", ""),
-        prefix=ee_symbol.info.prefix.replace(" ", ""),
+        name=ee_symbol.info.name,
+        prefix=ee_symbol.info.prefix,
         package=ee_symbol.info.package,
         manufacturer=ee_symbol.info.manufacturer,
         datasheet=ee_symbol.info.datasheet,
